@@ -112,6 +112,9 @@ class DataIndex(MutableMapping):
     def longest_prefix(self, *args, **kwargs):
         return self._trie.longest_prefix(*args, **kwargs)
 
+    def traverse(self, *args, **kwargs):
+        return self._trie.traverse(*args, **kwargs)
+
     def iteritems(self, prefix=None, shallow=False):
         kwargs = {"shallow": shallow}
         if prefix:
@@ -125,11 +128,34 @@ class DataIndex(MutableMapping):
             self._load(key, entry)
             yield key, entry
 
-    def ls(self, prefix=None):
-        kwargs = {}
-        if prefix:
-            kwargs["prefix"] = prefix
+    def info(self, key):
+        try:
+            entry = self[key]
+            isdir = entry.hash_info and entry.hash_info.isdir
+            return {
+                "type": "directory" if isdir else "file",
+                "size": entry.meta.size if entry.meta else 0,
+                "isexec": entry.meta.isexec if entry.meta else False,
+                "isdvc": True,
+                "isout": True,
+                "obj": entry.obj,
+                "entry": entry,
+                entry.hash_info.name: entry.hash_info.value,
+            }
+        except ShortKeyError:
+            return {
+                "type": "directory",
+                "size": 0,
+                "isexec": False,
+                "isdvc": bool(self.longest_prefix(key)),
+                "isout": False,
+                "obj": None,
+                "entry": None,
+            }
+        except KeyError as exc:
+            raise FileNotFoundError from exc
 
+    def _ensure_loaded(self, prefix):
         entry = self._trie.get(prefix)
         if (
             entry
@@ -141,17 +167,25 @@ class DataIndex(MutableMapping):
             if not entry.obj:
                 raise TreeError
 
-        ret = []
+    def ls(self, root_key, detail=True):
+        self._ensure_loaded(root_key)
+        if not detail:
 
-        def node_factory(_, key, children, *args):
-            if key == prefix:
-                list(children)
-            else:
-                ret.append(key[-1])
+            def node_factory(_, key, children, *args):
+                if key == root_key:
+                    return children
+                else:
+                    return key
 
-        self._trie.traverse(node_factory, **kwargs)
+        else:
 
-        return ret
+            def node_factory(_, key, children, *args):
+                if key == root_key:
+                    return children
+                else:
+                    return key, self.info(key)
+
+        return self.traverse(node_factory, prefix=root_key)
 
 
 def build(index, path, fs, **kwargs):
